asr.core.types
==============

.. automodule:: asr.core.types

   
   
   .. rubric:: Functions

   
   .. autofunction:: clickify_docstring
   
   

   
   
   .. rubric:: Classes

   
   .. autoclass:: AtomsFile
      :members:
   .. autoclass:: DictStr
      :members:
   
   

   
   
   